import { useContext } from "solid-js";
import { A } from "@solidjs/router";
import { LoginContext } from "./Root";
import { ModalContext } from "./Root";

function MenuItem(props: { href: string; children: any }) {
  return (
    <li>
      <A class="justify-center" href={props.href} end>
        {props.children}
      </A>
    </li>
  );
}

function Menu() {
  let login_ctx = useContext(LoginContext);
  return (
    <ul class="menu md:menu-horizontal rounded-box">
      <MenuItem href="/">Home</MenuItem>
      {login_ctx?.token() != "" && <MenuItem href="/new">New Post</MenuItem>}
    </ul>
  );
}

export function Navbar() {
  let modal_ctx = useContext(ModalContext);
  let login_ctx = useContext(LoginContext);

  const logout = () => {
    localStorage.setItem("token", "");
    localStorage.setItem("username", "");
    login_ctx?.setToken("");
    login_ctx?.setUsername("");
  };

  // Capitalize the first letter of the username
  const username =
    login_ctx && login_ctx.username()
      ? login_ctx.username().charAt(0).toUpperCase() +
        login_ctx.username().slice(1)
      : "Guest";

  return (
    <div class="navbar text-neutral-content max-w-3xl max-w rounded-box my-4">
      <div class="flex-1">
        <A href={"/"} class="btn btn-ghost normal-case text-xl">
          FrostByte
        </A>
      </div>
      <div class="flex">
        <Menu />
      </div>
      <div class="flex-1 justify-end flex">
        <A
          href="#"
          class="btn btn-ghost normal-case text-sm"
          onClick={() => {
            if (login_ctx?.token() != "") logout();
            else modal_ctx?.setLoginModalOpen(true);
          }}
        >
          {login_ctx?.token() != "" ? username : "Login"}
        </A>
      </div>
    </div>
  );
}
